#!/bin/sh
#
##

HACKNAME="touchblock"

# Pull libOTAUtils for logging & progress handling
[ -f ./libotautils5 ] && source ./libotautils5

HACKVER="1.3"

CONFIG_FILE="/etc/deviceConfig.conf"
CONFIG_FILE_BACKUP="/etc/deviceConfig.conf.bak"
CONFIG_FILE_MD5_1="839247de4cdb6bfac0989863db877d8e"    # FW 5.10.2 - 5.11.2
CONFIG_FILE_MD5_2="eb4136571b51bd7203eab2e0966bfb00"    # FW 5.12.1 - 5.13.5
CONFIG_FILE_MD5_3="ecc8818ba367fd199a227d386b8f70f3"    # FW 5.13.6
CONFIG_FILE_MD5_4="d1da53df04c13747e48a1c96fc9cbdb4"    # FW 5.14.1

CONFIG_FILE_DECRYPTED="/tmp/deviceConfigDecrypted.conf"
CONFIG_FILE_NEW_MD5_1="7193d166a3d235cb3b01043981c1830f"
CONFIG_FILE_NEW_MD5_2="eb0eaa8045cb48d4139dde005871c0a8"
CONFIG_FILE_NEW_MD5_3="6bcbdc40f05450f41f4895c0a8f8d253"
CONFIG_FILE_NEW_MD5_4="3ca5892005d22fdd536204a05afcba1f"

UPSTART_SCRIPT="xbath.conf"
UPSTART_PATH="/etc/upstart/"

# Result codes
OK=0
ERR=1

otautils_update_progressbar

# Check if original file does meet our md5 expectations:
case "$(md5sum $CONFIG_FILE | head -c32)" in
    $CONFIG_FILE_MD5_1 | $CONFIG_FILE_MD5_2 | $CONFIG_FILE_MD5_3 | $CONFIG_FILE_MD5_4)
        logmsg "I" "install" "" "$CONFIG_FILE md5 correct"
        ;;
    *)
        logmsg "C" "install" "" "$CONFIG_FILE md5sum mismatch, bailing out: $(md5sum $CONFIG_FILE | head -c32)"
        ;;
esac

otautils_update_progressbar

# Decrypt the configuration file
if ! devcap-encrypt -i $CONFIG_FILE $CONFIG_FILE_DECRYPTED; then
    logmsg "C" "install" "code=$?" "Unable to decrypt $CONFIG_FILE"
    return ${ERR}
fi

otautils_update_progressbar

# Update decrypted file content
if ! sed -i 's/\[common\]/\[common\]\nwaterproof.available=true/g' $CONFIG_FILE_DECRYPTED; then
    logmsg "C" "install" "code=$?" "Unable to update $CONFIG_FILE_DECRYPTED"
    return ${ERR}
fi

otautils_update_progressbar

# Check if new file checksum is correct
case "$(md5sum $CONFIG_FILE_DECRYPTED | head -c32)" in
    $CONFIG_FILE_NEW_MD5_1 | $CONFIG_FILE_NEW_MD5_2 | $CONFIG_FILE_NEW_MD5_3 | $CONFIG_FILE_NEW_MD5_3)
        logmsg "I" "install" "" "$CONFIG_FILE_DECRYPTED md5 correct"
        ;;
    *)
        logmsg "C" "install" "" "$CONFIG_FILE_DECRYPTED md5sum mismatch, bailing out: $(md5sum $CONFIG_FILE_DECRYPTED | head -c32)"
        ;;
esac

otautils_update_progressbar

# Mount root rw
if ! mntroot rw; then
    logmsg "C" "install" "code=$?" "Unable to update mount root rw"
    return ${ERR}
fi

otautils_update_progressbar

# Backup original config file
if ! cp $CONFIG_FILE $CONFIG_FILE_BACKUP; then
    logmsg "C" "install" "code=$?" "Unable to backup original config file"
    return ${ERR}
fi

otautils_update_progressbar

# Install the new config
if ! devcap-encrypt -i $CONFIG_FILE_DECRYPTED $CONFIG_FILE; then
    logmsg "C" "install" "code=$?" "Unable to install new, encrypted file"
    return ${ERR}
fi

otautils_update_progressbar

# Install the new upstart file
if ! cp $UPSTART_SCRIPT "${UPSTART_PATH}${UPSTART_SCRIPT}"; then
    logmsg "C" "install" "code=$?" "Unable to install the upstart file"
    return ${ERR}
fi

otautils_update_progressbar

# Mount root ro
if ! mntroot ro; then
    logmsg "W" "install" "code=$?" "Unable to mount root ro"
fi

otautils_update_progressbar

return ${OK}
